@@ -28,17 +28,15 @@ class Server:
             data = self.conn.recv(1024)
             if  data:
                 print(data)
-            if self.conn.fileno:
-                break;
-            if self.usbport != "":
                 try:
                     self.serial = serial.serial(self.usbport,9600)
                 except:
                     print("connct arduino properly")
                 self.serial.write(data)
-            else:
-                print(data)
+            if self.conn.fileno:
+                break;
 
+                
     def accept(self):
         """This function accepts the connection requested from client """
         self.s.listen(5)
